@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -223,7 +223,7 @@ class VpcAccessServiceAsyncClient:
         operation.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import vpcaccess_v1
 
@@ -348,7 +348,7 @@ class VpcAccessServiceAsyncClient:
         resource does not exist.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import vpcaccess_v1
 
@@ -438,7 +438,7 @@ class VpcAccessServiceAsyncClient:
     ) -> pagers.ListConnectorsAsyncPager:
         r"""Lists Serverless VPC Access connectors.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import vpcaccess_v1
 
@@ -540,7 +540,7 @@ class VpcAccessServiceAsyncClient:
         the resource does not exist.
 
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import vpcaccess_v1
 
